#!/bin/sh

######################################################################
# export all envinroment variables which are needed for getoradblogs2.sh back-end actuator script     #
######################################################################
export_env_variables()
{
    export PROPSFILE
    export CEA_GENACT_FUNCLIB
    export CEA_GENACT_DEBUG_LOG

    export ORACLE_SID
    export ORA_INSTANCE
    export ORA_USER
    export ORA_PWD
    export ORACLE_HOME 

    export TEMPFILE

    export TABLE_NAME
    export TABLE_NAME9
    export TABLE_NAME10
    export TABLE_DESC
    export TABLE_DESC9
    export TABLE_DESC10
    export TABLE_HEAD
    export TABLE_HEAD9
    export TABLE_HEAD10
    export COL_TIME
    export COL_TIME9
    export COL_TIME10
    export LINE_SIZE
    export GETHEADER
    export PARAM_OUTPUT
    export NOTIMESTAMP
    export TIMESTAMPNAME
    export NOLINESCHECK
}


# Source our function library. It contains generic functions. 
. $CEA_GENACT_FUNCLIB || exit 1

#######################################################
# Usage: err_exit <exit-code> [exit-message]
#######################################################
err_exit()
{
  debug $2
  debug "Warning: Processing finished with error \"$1\". "
  exit 0
}

CEA_GENACT_DEBUG_LOG="../log/cea_genact_debug_log.log"

if [ -z "${PROPSFILE}" ]; then err_exit 1 "Properties file must be specified!"; fi
CEA_GENACT_DEBUG_LOG="../log/${PROPSFILE}.log"
debug script $0 is running

if [ -z "${OPTION2}" ]; then err_exit 1 "Option #2 'Oracle Instance' must be specified!"; fi
if [ -z "${OPTION3}" ]; then err_exit 1 "Option #3 'Oracle User Name' must be specified!"; fi
if [ -z "${OPTION5}" ]; then err_exit 1 "Option #5 'Oracle Home Path' must be specified!"; fi

# Parameters needed for oracle access
ORACLE_SID="${OPTION2}"
ORA_INSTANCE="@${OPTION2}"
ORA_USER="${OPTION3}"
ORA_PWD="${OPTION4}"
ORACLE_HOME="${OPTION5}"

CEA_GENACT_DEBUG_LOG="../log/${PROPSFILE}.log"

TABLE_DESC9=""
TABLE_DESC10=""
TABLE_HEAD9=""
TABLE_HEAD10=""
TABLE_NAME9=""
TABLE_NAME10=""
COL_TIME9=""
COL_TIME10=""

##################################
# retrieve data from FND_AUDIT_GROUPS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE6}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_audit_groups_a tbl"
TABLE_DESC="tbl.*, 'fnd_audit_groups_a' as TABLENAME "
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_AUDIT_GROUPS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN STATE FORMAT A5;"
NOLINESCHECK=""

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_AUDIT_SCHEMAS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE7}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_audit_schemas_a tbl"
TABLE_DESC="tbl.*, 'fnd_audit_schemas_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_AUDIT_SCHEMAS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN STATE FORMAT A5;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_AUDIT_TABLES_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE8}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_audit_tables_a tbl"
TABLE_DESC="tbl.*, 'fnd_audit_tables_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_AUDIT_TABLES_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN STATE FORMAT A5;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_AUDIT_COLUMNS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE9}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_audit_columns_a tbl"
TABLE_DESC="tbl.*, 'fnd_audit_columns_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_AUDIT_COLUMNS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN STATE FORMAT A5;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from ALR_ALERTS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE10}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.alr_alerts_a tbl"
TABLE_DESC="tbl.*, 'alr_alerts_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="ALR_ALERTS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN ALERT_CONDITION_TYPE FORMAT A20;
COLUMN CHECK_BEGIN_DATE FORMAT A16;
COLUMN CHECK_ONCE_DAILY_FLAG FORMAT A21;
COLUMN CREATION_DATE FORMAT A13;
COLUMN DATE_LAST_CHECKED FORMAT A17;
COLUMN DELETE_FLAG FORMAT A11;
COLUMN ENABLED_FLAG FORMAT A12;
COLUMN END_DATE_ACTIVE FORMAT A15;
COLUMN FREQUENCY_TYPE FORMAT A14;
COLUMN INSERT_FLAG FORMAT A11;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN START_DATE_ACTIVE FORMAT A17;
COLUMN UPDATE_FLAG FORMAT A11;
COLUMN WEEKLY_CHECK_DAY FORMAT A16;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_ORACLE_USERID_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE11}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_oracle_userid_a tbl"
TABLE_DESC="tbl.*, 'fnd_oracle_userid_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_ORACLE_USERID_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN ENABLED_FLAG FORMAT A12;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN READ_ONLY_FLAG FORMAT A14;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_USER_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE12}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_user_a tbl"
TABLE_DESC="tbl.*, 'fnd_user_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_USER_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN END_DATE FORMAT A8;
COLUMN LAST_LOGON_DATE FORMAT A15;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN PASSWORD_DATE FORMAT A13;
COLUMN START_DATE FORMAT A10;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_USER_RESP_GROUPS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE13}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_user_resp_groups_a tbl"
TABLE_DESC="tbl.*, 'fnd_user_resp_groups_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_USER_RESP_GROUPS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh

	
##################################
# retrieve data from FND_FORM_FUNCTIONS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE14}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_form_functions_a tbl"
TABLE_DESC="tbl.*, 'fnd_form_functions_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_FORM_FUNCTIONS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN WEB_ENCRYPT_PARAMETERS FORMAT A22;
COLUMN WEB_SECURED FORMAT A11;
COLUMN CONTEXT_DEPENDENCE FORMAT A18;
COLUMN MAINTENANCE_MODE_SUPPORT FORMAT A24;
COLUMN IREP_COMPATIBILITY FORMAT A18;
COLUMN IREP_DIRECTION FORMAT A14;
COLUMN IREP_SYNCHRO FORMAT A12;
COLUMN IREP_SCHEMA_VALIDATION_FLAG FORMAT A27;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_MENUS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE15}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_menus_a tbl"
TABLE_DESC="tbl.*, 'fnd_menus_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_MENUS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_MENU_ENTRIES_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE16}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_menu_entries_a tbl"
TABLE_DESC="tbl.*, 'fnd_menu_entries_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_MENU_ENTRIES_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN GRANT_FLAG FORMAT A10;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_REQUEST_GROUPS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE17}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_request_groups_a tbl"
TABLE_DESC="tbl.*, 'fnd_request_groups_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_REQUEST_GROUPS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_REQUEST_GROUP_UNITS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE18}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_request_group_units_a tbl"
TABLE_DESC="tbl.*, 'fnd_request_group_units_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_REQUEST_GROUP_UNITS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN REQUEST_UNIT_TYPE FORMAT A17;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_ENABLED_PLSQL_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE19}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_enabled_plsql_a tbl"
TABLE_DESC="tbl.*, 'fnd_enabled_plsql_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_ENABLED_PLSQL_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN ENABLED FORMAT A7;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN EXTERNAL FORMAT A8;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_RESP_FUNCTIONS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE20}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_resp_functions_a tbl"
TABLE_DESC="tbl.*, 'fnd_resp_functions_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_RESP_FUNCTIONS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN RULE_TYPE FORMAT A9;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_CONCURRENT_PROGRAMS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE21}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_concurrent_programs_a tbl"
TABLE_DESC="tbl.*, 'fnd_concurrent_programs_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_CONCURRENT_PROGRAMS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN ARGUMENT_METHOD_CODE FORMAT A20;
COLUMN CREATION_DATE FORMAT A13;
COLUMN ENABLED_FLAG FORMAT A12;
COLUMN ENABLE_TIME_STATISTICS FORMAT A22;
COLUMN ENABLE_TRACE FORMAT A12;
COLUMN EXECUTION_METHOD_CODE FORMAT A21;
COLUMN LAST_UPDATE_DATE FORMAT A16;
COLUMN NLS_COMPLIANT FORMAT A13;
COLUMN OUTPUT_FILE_TYPE FORMAT A16;
COLUMN PRINT_FLAG FORMAT A10;
COLUMN QUEUE_CONTROL_FLAG FORMAT A18;
COLUMN QUEUE_METHOD_CODE FORMAT A17;
COLUMN REQUEST_SET_FLAG FORMAT A16;
COLUMN REQUIRED_STYLE FORMAT A14;
COLUMN RESTART FORMAT A7;
COLUMN RUN_ALONE_FLAG FORMAT A14;
COLUMN SAVE_OUTPUT_FLAG FORMAT A16;
COLUMN SRS_FLAG FORMAT A8;
COLUMN STAT_COLLECT FORMAT A12;
COLUMN PROGRAM_TYPE FORMAT A12;
COLUMN REFRESH_PORTLET FORMAT A15;
COLUMN ALLOW_MULTIPLE_PENDING_REQUEST FORMAT A30;
COLUMN DELETE_LOG_FILE FORMAT A15;
COLUMN MULTI_ORG_CATEGORY FORMAT A18;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_EXECUTABLES_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE22}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_executables_a tbl"
TABLE_DESC="tbl.*, 'fnd_executables_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_EXECUTABLES_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN EXECUTION_METHOD_CODE FORMAT A21;
COLUMN LAST_UPDATE_DATE FORMAT A16;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_DATA_GROUPS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE23}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_data_groups_a tbl"
TABLE_DESC="tbl.*, 'fnd_data_groups_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_DATA_GROUPS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A13;
COLUMN DEFAULT_GROUP_FLAG FORMAT A18;
COLUMN LAST_UPDATE_DATE FORMAT A16;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


##################################
# retrieve data from FND_DATA_GROUP_UNITS_A:

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE24}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_data_group_units_a tbl"
TABLE_DESC="tbl.*, 'fnd_data_group_units_a' as TABLENAME"
TABLE_HEAD=""
COL_TIME="audit_timestamp"
GETHEADER="YES"
TIMESTAMPNAME="FND_DATA_GROUP_UNITS_A"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN AUDIT_TIMESTAMP FORMAT A20;
COLUMN AUDIT_TRANSACTION_TYPE FORMAT A22;
COLUMN ROW_KEY FORMAT 9999999999999999999999999;
COLUMN CREATION_DATE FORMAT A20;
COLUMN LAST_UPDATE_DATE FORMAT A20;"

debug "Information: Processing table $TIMESTAMPNAME"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh

if [ -f "${PROPSFILE}.ok" ]
then 
  rm "${PROPSFILE}.ok"
  i=1
  while [ $i -le "24" ]
  do
    eval "tmpfile=\$TEMPFILE$i"
    if [ ! -f "$tmpfile" ]
    then
      echo "#Fields: ">"$tmpfile"
    fi  
    i=`expr $i + 1`
  done
  debug "Processing finished. [SUCCESS]"
else
  i=1
  while [ $i -le "24" ]
  do
    eval "tmpfile=\$TEMPFILE$i"
    if [ -f "$tmpfile" ]
    then
      rm -f "$tmpfile"
    fi  
    i=`expr $i + 1`
  done
  debug "Processing finished. [FAILURE]"
fi

